@@ -313,7 +313,6 @@ class TargetDependencyProject(enum.Enum):
     name_mapping={
         "affected_branch": "affectedBranch",
         "cacheable_operations": "cacheableOperations",
-        "implicit_dependencies": "implicitDependencies",
         "named_inputs": "namedInputs",
         "nx_cloud_read_only_access_token": "nxCloudReadOnlyAccessToken",
         "nx_ignore": "nxIgnore",
@@ -327,7 +326,6 @@ class WorkspaceConfig:
         *,
         affected_branch: typing.Optional[builtins.str] = None,
         cacheable_operations: typing.Optional[typing.Sequence[builtins.str]] = None,
-        implicit_dependencies: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[builtins.str]]] = None,
         named_inputs: typing.Optional[typing.Union[NamedInputs, typing.Dict[builtins.str, typing.Any]]] = None,
         nx_cloud_read_only_access_token: typing.Optional[builtins.str] = None,
         nx_ignore: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -338,7 +336,6 @@ class WorkspaceConfig:
 
         :param affected_branch: Affected branch. Default: mainline
         :param cacheable_operations: Defines the list of targets/operations that are cached by Nx. Default: ["build", "test"]
-        :param implicit_dependencies: Configuration for Implicit Dependencies.
         :param named_inputs: Named inputs.
         :param nx_cloud_read_only_access_token: Read only access token if enabling nx cloud.
         :param nx_ignore: List of patterns to include in the .nxignore file.
@@ -355,7 +352,6 @@ class WorkspaceConfig:
             type_hints = typing.get_type_hints(_typecheckingstub__b5621333d7a417790081a88ae66edb9efb72f78d591ce7ca8add40d8274ecfda)
             check_type(argname="argument affected_branch", value=affected_branch, expected_type=type_hints["affected_branch"])
             check_type(argname="argument cacheable_operations", value=cacheable_operations, expected_type=type_hints["cacheable_operations"])
-            check_type(argname="argument implicit_dependencies", value=implicit_dependencies, expected_type=type_hints["implicit_dependencies"])
             check_type(argname="argument named_inputs", value=named_inputs, expected_type=type_hints["named_inputs"])
             check_type(argname="argument nx_cloud_read_only_access_token", value=nx_cloud_read_only_access_token, expected_type=type_hints["nx_cloud_read_only_access_token"])
             check_type(argname="argument nx_ignore", value=nx_ignore, expected_type=type_hints["nx_ignore"])
@@ -366,8 +362,6 @@ class WorkspaceConfig:
             self._values["affected_branch"] = affected_branch
         if cacheable_operations is not None:
             self._values["cacheable_operations"] = cacheable_operations
-        if implicit_dependencies is not None:
-            self._values["implicit_dependencies"] = implicit_dependencies
         if named_inputs is not None:
             self._values["named_inputs"] = named_inputs
         if nx_cloud_read_only_access_token is not None:
@@ -399,17 +393,6 @@ class WorkspaceConfig:
         result = self._values.get("cacheable_operations")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
-    @builtins.property
-    def implicit_dependencies(
-        self,
-    ) -> typing.Optional[typing.Mapping[builtins.str, typing.List[builtins.str]]]:
-        '''Configuration for Implicit Dependencies.
-
-        :see: https://nx.dev/configuration/packagejson#implicitdependencies
-        '''
-        result = self._values.get("implicit_dependencies")
-        return typing.cast(typing.Optional[typing.Mapping[builtins.str, typing.List[builtins.str]]], result)
-
     @builtins.property
     def named_inputs(self) -> typing.Optional[NamedInputs]:
         '''Named inputs.
@@ -510,7 +493,6 @@ def _typecheckingstub__b5621333d7a417790081a88ae66edb9efb72f78d591ce7ca8add40d82
     *,
     affected_branch: typing.Optional[builtins.str] = None,
     cacheable_operations: typing.Optional[typing.Sequence[builtins.str]] = None,
-    implicit_dependencies: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[builtins.str]]] = None,
     named_inputs: typing.Optional[typing.Union[NamedInputs, typing.Dict[builtins.str, typing.Any]]] = None,
     nx_cloud_read_only_access_token: typing.Optional[builtins.str] = None,
     nx_ignore: typing.Optional[typing.Sequence[builtins.str]] = None,
